==> snipe-it-6.3.0.zip: snipe-it-6.3.0/resources/lang/bg-BG/admin/hardware/form.php <==
<?php

return [
    'bulk_delete'		=> 'Потвърдете масовото изтриване на активи',
    'bulk_restore'      => 'Потвърдете масовото възстановяване на активите', 
  'bulk_delete_help'	=> 'Прегледайте активите, маркирани за масово изтриване. Веднъж изтрити, активите могат да бъдат възстановени, но те вече няма да бъдат асоциирани с потребителите, на които са изписани в момента.',
  'bulk_restore_help'	=> 'Прегледайте активите за масово възстановяване по-долу. Веднъж след като се възстановят, тези активи няма да бъдат зачислените към потребителите, където преди това са били.',
  'bulk_delete_warn'	=> 'Ще бъдат изтрити :asset_count актива.',
  'bulk_restore_warn'	=> 'Ще бъдата възстановени :asset_count актива.',
    'bulk_update'		=> 'Масово обновяване на активи',
    'bulk_update_help'	=> 'Тук можете да обновите множество активи едновременно. Попълнете единствено полетата, които желаете да промените. Всички празни полета няма да бъдат променени.',
    'bulk_update_warn'	=> 'Ще редактирате настройките на един актив.|Ще редактирате настройките на :asset_count актива.',
    'bulk_update_with_custom_field' => 'Въпросните :asset_model_count актива са от различен тип модели.',
    'bulk_update_model_prefix' => 'От Модели', 
    'bulk_update_custom_field_unique' => 'Това е уникално поле и не може да бъде редактирано едновременно.',
    'checkedout_to'		=> 'Изписано на',
    'checkout_date'		=> 'Дата на изписване',
    'checkin_date'		=> 'Дата на вписване',
    'checkout_to'		=> 'Изпиши на',
    'cost'				=> 'Стойност на закупуване',
    'create'			=> 'Създаване на актив',
    'date'				=> 'Дата на закупуване',
    'depreciation'	    => 'амортизация',
    'depreciates_on'	=> 'Амортизира се на',
    'default_location'	=> 'Местоположение по подразбиране',
    'default_location_phone' => 'Default Location Phone',
    'eol_date'			=> 'EOL дата',
    'eol_rate'			=> 'EOL съотношение',
    'expected_checkin'  => 'Очаквана дата на вписване',
    'expires'			=> 'Изтича',
    'fully_depreciated'	=> 'Напълно амортизиран',
    'help_checkout'		=> 'Ако желаете да присвоите актив на момента, изберете "Готово за предаване" от списъка по-горе.',
    'mac_address'		=> 'MAC адрес',
    'manufacturer'		=> 'Производител',
    'model'				=> 'Модел',
    'months'			=> 'месеца',
    'name'				=> 'Име на актив',
    'notes'				=> 'Бележки',
    'order'				=> 'Номер на поръчка',
    'qr'				=> 'QR код',
    'requestable'		=> 'Потребителите могат да изписват актива',
    'select_statustype'	=> 'Избиране на тип на статуса',
    'serial'			=> 'Сериен номер',
    'status'			=> 'Статус',
    'tag'				=> 'Инвентарен номер',
    'update'			=> 'Обновяване на актив',
    'warranty'			=> 'Гаранция',
        'warranty_expires'		=> 'Гаранцията изтича',
    'years'				=> 'години',
    'asset_location' => 'Обновяване на местоположение',
    'asset_location_update_default_current' => 'Актуализиране на местоположение по подразбиране и текущото местоположение',
    'asset_location_update_default' => 'Актуализиране на местоположението по подразбиране',
    'asset_location_update_actual' => 'Update only actual location',
    'asset_not_deployable' => 'Актива не може да бъде предоставен. Този активк не може да бъде изписан.',
    'asset_deployable' => 'Актива може да бъде предоставен. Този активк може да бъде изписан.',
    'processing_spinner' => 'Обработка...(Това може да отнеме време при големи файлове)',
    'optional_infos'  => 'Допълнителна информация',
    'order_details'   => 'Информация за състоянието на поръчка'
];

==> snipe-it-7.0.11.zip: snipe-it-7.0.11/resources/lang/bg-BG/admin/hardware/form.php <==
<?php

return [
    'bulk_delete'		=> 'Потвърдете масовото изтриване на активи',
    'bulk_restore'      => 'Потвърдете масовото възстановяване на активите', 
  'bulk_delete_help'	=> 'Прегледайте активите, маркирани за масово изтриване. Веднъж изтрити, активите могат да бъдат възстановени, но те вече няма да бъдат асоциирани с потребителите, на които са изписани в момента.',
  'bulk_restore_help'	=> 'Прегледайте активите за масово възстановяване по-долу. Веднъж след като се възстановят, тези активи няма да бъдат зачислените към потребителите, където преди това са били.',
  'bulk_delete_warn'	=> 'Ще бъдат изтрити :asset_count актива.',
  'bulk_restore_warn'	=> 'Ще бъдата възстановени :asset_count актива.',
    'bulk_update'		=> 'Масово обновяване на активи',
    'bulk_update_help'	=> 'Тук можете да обновите множество активи едновременно. Попълнете единствено полетата, които желаете да промените. Всички празни полета няма да бъдат променени.',
    'bulk_update_warn'	=> 'Ще редактирате настройките на един актив.|Ще редактирате настройките на :asset_count актива.',
    'bulk_update_with_custom_field' => 'Въпросните :asset_model_count актива са от различен тип модели.',
    'bulk_update_model_prefix' => 'От Модели', 
    'bulk_update_custom_field_unique' => 'Това е уникално поле и не може да бъде редактирано едновременно.',
    'checkedout_to'		=> 'Изписано на',
    'checkout_date'		=> 'Дата на изписване',
    'checkin_date'		=> 'Дата на вписване',
    'checkout_to'		=> 'Изпиши на',
    'cost'				=> 'Стойност на закупуване',
    'create'			=> 'Създаване на актив',
    'date'				=> 'Дата на закупуване',
    'depreciation'	    => 'амортизация',
    'depreciates_on'	=> 'Амортизира се на',
    'default_location'	=> 'Местоположение по подразбиране',
    'default_location_phone' => 'Телефон на местоположението по подразбиране',
    'eol_date'			=> 'EOL дата',
    'eol_rate'			=> 'EOL съотношение',
    'expected_checkin'  => 'Очаквана дата на вписване',
    'expires'			=> 'Изтича',
    'fully_depreciated'	=> 'Напълно амортизиран',
    'help_checkout'		=> 'Ако желаете да присвоите актив на момента, изберете "Готово за предаване" от списъка по-горе.',
    'mac_address'		=> 'MAC адрес',
    'manufacturer'		=> 'Производител',
    'model'				=> 'Модел',
    'months'			=> 'месеца',
    'name'				=> 'Име на актив',
    'notes'				=> 'Бележки',
    'order'				=> 'Номер на поръчка',
    'qr'				=> 'QR код',
    'requestable'		=> 'Потребителите могат да изписват актива',
    'redirect_to_all'   => 'Връщане към всички :type',
    'redirect_to_type'   => 'Отидете на :type',
    'redirect_to_checked_out_to'   => 'Отидете на Checked Out to',
    'select_statustype'	=> 'Избиране на тип на статуса',
    'serial'			=> 'Сериен номер',
    'status'			=> 'Статус',
    'tag'				=> 'Инвентарен номер',
    'update'			=> 'Обновяване на актив',
    'warranty'			=> 'Гаранция',
        'warranty_expires'		=> 'Гаранцията изтича',
    'years'				=> 'години',
    'asset_location' => 'Обновяване на местоположение',
    'asset_location_update_default_current' => 'Актуализиране на местоположение по подразбиране и текущото местоположение',
    'asset_location_update_default' => 'Актуализиране на местоположението по подразбиране',
    'asset_location_update_actual' => 'Актуализиране само на местоположението',
    'asset_not_deployable' => 'Актива не може да бъде предоставен. Този активк не може да бъде изписан.',
    'asset_deployable' => 'Актива може да бъде предоставен. Този активк може да бъде изписан.',
    'processing_spinner' => 'Обработка...(Това може да отнеме време при големи файлове)',
    'optional_infos'  => 'Допълнителна информация',
    'order_details'   => 'Информация за състоянието на поръчка'
];
